=============
Sample charts
=============

All of the charts on this page were produced by agate-charts with a single line of code each.

Single series
=============

Lines
-----

.. image:: samples/line_chart_simple.png

Columns
-------

.. image:: samples/column_chart_simple.png

Bars
----

.. image:: samples/bar_chart_simple.png

Scatter
-------

.. image:: samples/scatter_chart.png

Time series
===========

Lines
-----

.. image:: samples/line_chart_dates.png

Columns
-------

.. image:: samples/column_chart_dates.png

Bars
----

.. image:: samples/bar_chart_dates.png

Multiple series
===============

Lines
-----

.. image:: samples/line_chart_complex.png

Columns
-------

.. image:: samples/column_chart_complex.png

Bars
----

.. image:: samples/bar_chart_complex.png

Small multiples
===============

Lines
-----

.. image:: samples/line_chart_simple_multiples.png

Columns
-------

.. image:: samples/column_chart_simple_multiples.png

Bars
----

.. image:: samples/bar_chart_simple_multiples.png

Scatter
-------

.. image:: samples/scatter_chart_multiples.png

Small multiples and multiple series
===================================

Lines
-----

.. image:: samples/line_chart_complex_multiples.png

Columns
-------

.. image:: samples/column_chart_complex_multiples.png

Bars
----

.. image:: samples/bar_chart_complex_multiples.png
